==> haskell-optparse-generic-1.5.2-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-generic
version:              1.5.2
visibility:           public
id:                   optparse-generic-1.5.2-6pvlfVSuUcxJDViuGjChsn
key:                  optparse-generic-1.5.2-6pvlfVSuUcxJDViuGjChsn
license:              BSD-3-Clause
copyright:            2016 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  245687d199b0621b0e1be608533acdf0
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-generic
hs-libraries:         HSoptparse-generic-1.5.2-6pvlfVSuUcxJDViuGjChsn
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 base-4.17.2.1 bytestring-0.11.5.3
    filepath-1.4.2.2
    optparse-applicative-0.18.1.0-B5S7p3yvcpkHKfw0kuCuBU text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-generic-1.5.2-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-generic
version:              1.5.2
visibility:           public
id:                   optparse-generic-1.5.2-5i2jMnZT0PE31LTKQ1t729
key:                  optparse-generic-1.5.2-5i2jMnZT0PE31LTKQ1t729
license:              BSD-3-Clause
copyright:            2016 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  55ef3d4cdd3fc10199ef24b76491d431
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-generic
hs-libraries:         HSoptparse-generic-1.5.2-5i2jMnZT0PE31LTKQ1t729
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 base-4.17.2.1 bytestring-0.11.5.3
    filepath-1.4.2.2
    optparse-applicative-0.18.1.0-6krVryETStC73hI3cDgd1Y text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
